@@ -130,7 +130,7 @@ def parse_mi_xml(xml_str: str) -> Union[MiData, MiError]:
     '''
     miError = _has_mi_error(xml_str)
 
-    if not miError:
+    if miError:
         return miError
 
     else:
